@@ -8,8 +8,8 @@ use strict;
 
 ########################################################
 # Specify version and build-date:
-my $Version = '7.4.0';
-my $VDate = '03/01/11';
+my $Version = '7.4.3';
+my $VDate = '04/27/16';
 
 #######################################################
 # Logwatch was written and is maintained by:
@@ -87,6 +87,7 @@ $Config{'numeric'} = 0;
 $Config{'pathtocat'} = "cat";
 $Config{'pathtozcat'} = "zcat";
 $Config{'pathtobzcat'} = "bzcat";
+$Config{'pathtoxzcat'} = "xzcat";
 $Config{'output'} = "stdout"; #8.0
 $Config{'format'} = "text"; #8.0
 $Config{'encode'} = "none"; #8.0
@@ -767,6 +768,10 @@ foreach $LogFile (@LogFileList) {
             my $arguments = "'${Archive}' 2>/dev/null >> $DestFile";
             system("$Config{'pathtobzcat'} $arguments") == 0
                or die "system '$Config{'pathtobzcat'} $arguments' failed: $?"
+         } elsif (($Archive =~ m/xz$/) && (-f "$Archive") && (-s "$Archive")) {
+            my $arguments = "'${Archive}' 2>/dev/null >> $DestFile";
+            system("$Config{'pathtoxzcat'} $arguments") == 0
+               or die "system '$Config{'pathtoxzcat'} $arguments' failed: $?"
          } elsif ((-f "$Archive") && (-s "$Archive")) {
             my $arguments = "'${Archive}'  >> $DestFile";
             system("$Config{'pathtocat'} $arguments") == 0
@@ -1292,6 +1297,24 @@ sub parselogs {
             }
          }
       }
+      # set env variables LOGWATCH_mumble_LIST
+      push @EnvList, 'LOGWATCH_LOGFILE_LIST';
+      push @EnvList, 'LOGWATCH_ARCHIVE_LIST';
+      $ENV{'LOGWATCH_LOGFILE_LIST'} = '';
+      $ENV{'LOGWATCH_ARCHIVE_LIST'} = '';
+      foreach my $LogGroup (@FileList) {
+         foreach my $log (@{$LogFileData{$LogGroup}{'logfiles'}}) {
+            $ENV{'LOGWATCH_LOGFILE_LIST'} .= $log . " ";
+         }
+         foreach my $archive (@{$LogFileData{$LogGroup}{'archives'}}) {
+            $ENV{'LOGWATCH_ARCHIVE_LIST'} .= $archive . " ";
+         }
+      }
+      if ($Config{'debug'}>4) {
+         print "\nexport LOGWATCH_LOGFILE_LIST='$ENV{LOGWATCH_LOGFILE_LIST}'";
+         print "\nexport LOGWATCH_ARCHIVE_LIST='$ENV{LOGWATCH_ARCHIVE_LIST}'";
+      }
+
       # ECP - insert the host stripping now
       my $HostStrip = " ";
       if ($Config{'hostformat'} ne "none") { #8.0
